@@ -23,6 +23,15 @@ from gi.repository import GLib, GObject, Gio, Gedit
 import sys, os
 import commander.commands as commands
 
+try:
+    import gettext
+    gettext.bindtextdomain('gedit-plugins')
+    gettext.textdomain('gedit-plugins')
+    _ = gettext.gettext
+except:
+    _ = lambda s: s
+
+
 class CommanderAppActivatable(GObject.Object, Gedit.AppActivatable):
 
     app = GObject.Property(type=Gedit.App)
@@ -56,4 +65,4 @@ class CommanderAppActivatable(GObject.Object, Gedit.AppActivatable):
         self.app.remove_accelerator("win.commander", None)
         self.menu_ext = None
 
-# vi:ex:ts=4:et
+# ex:ts=4:et
